Changes
===============

0.0.1 (2022-05-22)
----------------

* Completely refactored the codeabase to introduce Google Tink based primitives

* Extended support to working with multiple keysets and providing associated data for AEAD

* Removed supoort for legacy Python and Django
